@@ -204,6 +204,41 @@ class AudioInfo(AbstractModel):
         
 
 
+class ClassifiedPersonInfo(AbstractModel):
+    """已分类的人物信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClassifyName: 人物分类名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ClassifyName: str
+        :param PersonInfoSet: 符合特定分类的人物信息数组
+注意：此字段可能返回 null，表示取不到有效值。
+        :type PersonInfoSet: list of PersonInfo
+        """
+        self.ClassifyName = None
+        self.PersonInfoSet = None
+
+
+    def _deserialize(self, params):
+        self.ClassifyName = params.get("ClassifyName")
+        if params.get("PersonInfoSet") is not None:
+            self.PersonInfoSet = []
+            for item in params.get("PersonInfoSet"):
+                obj = PersonInfo()
+                obj._deserialize(item)
+                self.PersonInfoSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class CreateCustomCategoryRequest(AbstractModel):
     """CreateCustomCategory请求参数结构体
 
@@ -1160,6 +1195,7 @@ class DescribeTaskDetailResponse(AbstractModel):
     def __init__(self):
         r"""
         :param TaskInfo: 任务信息，不包含任务结果
+注意：此字段可能返回 null，表示取不到有效值。
         :type TaskInfo: :class:`tencentcloud.ivld.v20210903.models.TaskInfo`
         :param TaskData: 任务结果数据，只在任务结束时返回
         :type TaskData: :class:`tencentcloud.ivld.v20210903.models.Data`
@@ -1313,7 +1349,8 @@ class ImportMediaRequest(AbstractModel):
         :type MD5: str
         :param Name: 待分析视频的名称，指定后可支持筛选，最多100个中文字符
         :type Name: str
-        :param WriteBackCosPath: 当非本人外部视频地址导入时，该字段为转存的cos桶地址且不可为空; 示例：https://${Bucket}-${AppId}.cos.${Region}.myqcloud.com/${PathPrefix}/  (注意，cos路径需要以/分隔符结尾)
+        :param WriteBackCosPath: 当非本人外部视频地址导入时，该字段为转存的cos桶地址且不可为空; 示例：https://${Bucket}-${AppId}.cos.${Region}.myqcloud.com/${PathPrefix}/  (注意，cos路径需要以/分隔符结尾)。
+推荐采用本主帐号COS桶，如果使用其他帐号COS桶，请确保COS桶可写，否则可导致分析失败
         :type WriteBackCosPath: str
         :param Label: 自定义标签，可用于查询
         :type Label: str
@@ -1594,6 +1631,9 @@ class MediaInfo(AbstractModel):
         :param Label: 媒资自定义标签
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
+        :param CallbackURL: 媒资导入完成后的回调地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CallbackURL: str
         """
         self.MediaId = None
         self.Name = None
@@ -1603,6 +1643,7 @@ class MediaInfo(AbstractModel):
         self.Metadata = None
         self.Progress = None
         self.Label = None
+        self.CallbackURL = None
 
 
     def _deserialize(self, params):
@@ -1616,6 +1657,7 @@ class MediaInfo(AbstractModel):
             self.Metadata._deserialize(params.get("Metadata"))
         self.Progress = params.get("Progress")
         self.Label = params.get("Label")
+        self.CallbackURL = params.get("CallbackURL")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1879,6 +1921,44 @@ class PersonImageInfo(AbstractModel):
         
 
 
+class PersonInfo(AbstractModel):
+    """人物信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Name: 公众人物姓名
+        :type Name: str
+        :param Job: 公众人物职务
+        :type Job: str
+        :param FirstAppear: 首次出现模态，可选值为[1,3]，详细参见AppearIndex定义
+        :type FirstAppear: int
+        :param AppearInfo: 人物出现信息
+        :type AppearInfo: :class:`tencentcloud.ivld.v20210903.models.AppearInfo`
+        """
+        self.Name = None
+        self.Job = None
+        self.FirstAppear = None
+        self.AppearInfo = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.Job = params.get("Job")
+        self.FirstAppear = params.get("FirstAppear")
+        if params.get("AppearInfo") is not None:
+            self.AppearInfo = AppearInfo()
+            self.AppearInfo._deserialize(params.get("AppearInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class QueryCallbackRequest(AbstractModel):
     """QueryCallback请求参数结构体
 
@@ -1944,6 +2024,9 @@ class ShowInfo(AbstractModel):
         :param TextInfoSet: 可视文字识别结果列表
 注意：此字段可能返回 null，表示取不到有效值。
         :type TextInfoSet: list of TextInfo
+        :param ClassifiedPersonInfoSet: 已分类人物信息列表
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ClassifiedPersonInfoSet: list of ClassifiedPersonInfo
         :param TextTagSet: 文本标签列表，包含标签内容和出现信息
 注意：此字段可能返回 null，表示取不到有效值。
         :type TextTagSet: :class:`tencentcloud.ivld.v20210903.models.MultiLevelTag`
@@ -1969,6 +2052,7 @@ class ShowInfo(AbstractModel):
         self.TitleSet = None
         self.AudioInfoSet = None
         self.TextInfoSet = None
+        self.ClassifiedPersonInfoSet = None
         self.TextTagSet = None
         self.FrameTagSet = None
         self.WebMediaURL = None
@@ -1996,6 +2080,12 @@ class ShowInfo(AbstractModel):
                 obj = TextInfo()
                 obj._deserialize(item)
                 self.TextInfoSet.append(obj)
+        if params.get("ClassifiedPersonInfoSet") is not None:
+            self.ClassifiedPersonInfoSet = []
+            for item in params.get("ClassifiedPersonInfoSet"):
+                obj = ClassifiedPersonInfo()
+                obj._deserialize(item)
+                self.ClassifiedPersonInfoSet.append(obj)
         if params.get("TextTagSet") is not None:
             self.TextTagSet = MultiLevelTag()
             self.TextTagSet._deserialize(params.get("TextTagSet"))
@@ -2147,6 +2237,9 @@ class TaskInfo(AbstractModel):
         :param Label: 媒资自定义标签
 注意：此字段可能返回 null，表示取不到有效值。
         :type Label: str
+        :param CallbackURL: 任务分析完成后的后调地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CallbackURL: str
         """
         self.TaskId = None
         self.TaskName = None
@@ -2160,6 +2253,7 @@ class TaskInfo(AbstractModel):
         self.MediaPreknownInfo = None
         self.MediaName = None
         self.Label = None
+        self.CallbackURL = None
 
 
     def _deserialize(self, params):
@@ -2177,6 +2271,7 @@ class TaskInfo(AbstractModel):
             self.MediaPreknownInfo._deserialize(params.get("MediaPreknownInfo"))
         self.MediaName = params.get("MediaName")
         self.Label = params.get("Label")
+        self.CallbackURL = params.get("CallbackURL")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
