@@ -17,6 +17,9 @@
 # 请求响应超时。
 INTERNALERROR_ACTIONREADTIMEOUT = 'InternalError.ActionReadTimeout'
 
+# 添加子网/虚拟节点异常。
+INTERNALERROR_ADDNEWNODEERROR = 'InternalError.AddNewNodeError'
+
 # 创建apm资源失败。
 INTERNALERROR_CREATEAPMRESOURCEERROR = 'InternalError.CreateApmResourceError'
 
@@ -29,6 +32,9 @@ INTERNALERROR_CREATESERVICEERROR = 'InternalError.CreateServiceError'
 # 服务器繁忙,请稍后再试。
 INTERNALERROR_DEFAULTINTERNALERROR = 'InternalError.DefaultInternalError'
 
+# 删除 ingress 失败。
+INTERNALERROR_DELETEINGRESSERROR = 'InternalError.DeleteIngressError'
+
 # 删除应用失败。
 INTERNALERROR_DELETESERVICEERROR = 'InternalError.DeleteServiceError'
 
@@ -41,6 +47,9 @@ INTERNALERROR_DESCRIBERUNPODLISTERROR = 'InternalError.DescribeRunPodListError'
 # 查询服务关联的 ingress 失败。
 INTERNALERROR_DESCRIBESERVICEINGRESSERROR = 'InternalError.DescribeServiceIngressError'
 
+# 查询service列表失败。
+INTERNALERROR_DESCRIBESERVICELISTERROR = 'InternalError.DescribeServiceListError'
+
 # 重启失败。
 INTERNALERROR_RESTARTAPPLICATIONERROR = 'InternalError.RestartApplicationError'
 
@@ -80,6 +89,9 @@ INVALIDPARAMETERVALUE_SERVICELOWERCASE = 'InvalidParameterValue.ServiceLowerCase
 # 应用名已存在。
 INVALIDPARAMETERVALUE_SERVICENAMEDUPLICATEERROR = 'InvalidParameterValue.ServiceNameDuplicateError'
 
+# 实例创建失败，达到上限。
+INVALIDPARAMETERVALUE_SERVICEPODREACHMAXIMUM = 'InvalidParameterValue.ServicePodReachMaximum'
+
 # 应用创建失败，达到上限。
 INVALIDPARAMETERVALUE_SERVICEREACHMAXIMUM = 'InvalidParameterValue.ServiceReachMaximum'
 
@@ -104,6 +116,12 @@ MISSINGPARAMETER_PKGNAMENULL = 'MissingParameter.PkgNameNull'
 # 服务ID不能为空。
 MISSINGPARAMETER_SERVICEIDNULL = 'MissingParameter.ServiceIdNull'
 
+# 镜像仓库还未就绪。
+MISSINGPARAMETER_SVCREPONOTREADY = 'MissingParameter.SvcRepoNotReady'
+
+# 你操作的资源已被其他操作占用，请稍后重试。
+RESOURCEINUSE_RESOURCEALREADYLOCKED = 'ResourceInUse.ResourceAlreadyLocked'
+
 # 资源已绑定。
 RESOURCEINUSE_RESOURCEALREADYUSED = 'ResourceInUse.ResourceAlreadyUsed'
 
